<%page expression_filter="h"/>
<%!
from django.utils.translation import gettext as _
from openedx.core.djangolib.markup import HTML, Text
%>
<!-- NEW IN INDIGO update icon -->
<div class="profile-sidebar" role="region" aria-labelledby="account-activation-title">
  <header class="profile">
    <h2 id="account-activation-title" class="account-activation-title sr">${_("Account Activation Info")}: </h2>
  </header>
  <div class="user-info">
    <ul>
      <li class="status status-verification warning" aria-labelledby="status-title" tabindex="-1">
        <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 20 20" fill="none">
          <path fill-rule="evenodd" clip-rule="evenodd" d="M8.25706 3.09882C9.02167 1.73952 10.9788 1.73952 11.7434 3.09882L17.3237 13.0194C18.0736 14.3526 17.1102 15.9999 15.5805 15.9999H4.4199C2.89025 15.9999 1.92682 14.3526 2.67675 13.0194L8.25706 3.09882ZM11.0001 13C11.0001 13.5523 10.5524 14 10.0001 14C9.44784 14 9.00012 13.5523 9.00012 13C9.00012 12.4477 9.44784 12 10.0001 12C10.5524 12 11.0001 12.4477 11.0001 13ZM10.0001 5C9.44784 5 9.00012 5.44772 9.00012 6V9C9.00012 9.55228 9.44784 10 10.0001 10C10.5524 10 11.0001 9.55228 11.0001 9V6C11.0001 5.44772 10.5524 5 10.0001 5Z" fill="#FBBF24"/>
        </svg>
        <span id="status-title" class="title status-title">
          <span class="sr">Notice</span>
          ${_("Activate your account!")}
        </span>
        <p class="status-note">${ activate_account_message | n, decode.utf8 }</p>
        ## TODO: Add resend activation email functionality.
        ## TODO: Implementation of this is part of ENT-353.
        ## <button class="btn btn-neutral"><i class="fa fa-envelope-o"></i> Resend Activation Email </button>
      </li>
    </ul>
  </div>
</div>
